
# **Roadmap para o ano de 2025**

- **Janeiro**  
  - [] Expansão da base de Agentes para 20 agentes



- **Fevereiro**  
  - [X] 

- **Março**  
  - [X] 


- **Abril**  
  - [X] 


- **Maio**  
  - [X] 


- **Junho**  
  - [X] 


- **Julho**  
  - [X] 


- **Agosto**  
  - [X] 


- **Setembro**  
  - [X] 


- **Outubro**  
  - [X] 


- **Dezembro**  
  - [X] 

